@@ -17,6 +17,7 @@
 #include <sys/types.h>
 #include <dirent.h>
 #include <string.h>
+#include <unistd.h>
 
 ///////////////////////////////////////////////////////////////////
 
@@ -34,8 +35,8 @@
 
 ///////////////////////////////////////////////////////////////////
 
-static int num_versions=2; // number of different weed api versions supported
-static int api_versions[]={131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
+static int num_versions=1; // number of different weed api versions supported
+static int api_versions[]={131}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
 
 static int package_version=1; // version of this package
 
@@ -60,7 +61,7 @@ typedef void (*f0r_update_f)(f0r_instance_t instance, double time, const uint32_
 typedef void (*f0r_update2_f)(f0r_instance_t instance, double time, const uint32_t *inframe1, const uint32_t *inframe2, const uint32_t *inframe3, uint32_t *outframe);
 typedef void (*f0r_set_param_value_f)(f0r_instance_t *instance, f0r_param_t *param, int param_index);
 
-#if FREI0R_MAJOR_VERSION > 1 || FREI0R_MINOR_VERSION > 1
+#if FREI0R_MAJOR_VERSION >1 || FREI0R_MINOR_VERSION > 1
 #define CAN_GET_DEF
 typedef void (*f0r_get_param_value_f)(f0r_instance_t *instance, f0r_param_t *param, int param_index);
 #endif
@@ -96,15 +97,20 @@ static void getenv_piece(char * target, size_t tlen, char *envvar, int num) {
 
 int frei0r_init (weed_plant_t *inst) {
   weed_plant_t *out_channel,*filter;
-  int error,height,width;
+  int error,height,width,cpalette;
   f0r_instance_t f0r_inst;
   f0r_construct_f f0r_construct;
 
   filter=weed_get_plantptr_value(inst,"filter_class",&error);
 
   out_channel=weed_get_plantptr_value(inst,"out_channels",&error);
-  width=weed_get_int_value(out_channel,"rowstrides",&error)>>2;
+  width=weed_get_int_value(out_channel,"rowstrides",&error);
   height=weed_get_int_value(out_channel,"height",&error);
+  cpalette=weed_get_int_value(out_channel,"current_palette",&error);
+
+  if (cpalette==WEED_PALETTE_UYVY||cpalette==WEED_PALETTE_YUYV) width>>=1;
+  else width>>=2;
+
 
   f0r_construct=weed_get_voidptr_value(filter,"plugin_f0r_construct",&error);
 
@@ -174,7 +180,7 @@ static void weed_params_to_frei0r_params (weed_plant_t *inst, weed_plant_t **in_
       break;
     case WEED_HINT_TEXT:
       string=weed_get_string_value(in_params[i],"value",&error);
-      (*f0r_set_param_value)(f0rinst,(f0r_param_t)string,pnum);
+      (*f0r_set_param_value)(f0rinst,(f0r_param_t)&string,pnum);
       weed_free(string);
       break;
     }
@@ -246,7 +252,7 @@ int frei0r_process (weed_plant_t *inst, weed_timecode_t timestamp) {
 
 weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
   weed_plant_t *plugin_info;
-  if (FREI0R_MAJOR_VERSION!=1||FREI0R_MINOR_VERSION!=1) return NULL;
+  if (FREI0R_MAJOR_VERSION<1||FREI0R_MINOR_VERSION<1) return NULL;
 
   plugin_info=weed_plugin_info_init(weed_boot,num_versions,api_versions);
 
@@ -301,6 +307,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
     char *valch;
     f0r_param_color_t valcol;
     f0r_param_position_t valpos;
+    int is_unstable;
 
 #ifdef CAN_GET_DEF
   f0r_instance_t f0r_inst;
@@ -308,6 +315,14 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 #endif
 
     char *fpp=getenv("FREI0R_PATH");
+
+#ifndef DEBUG
+    int new_stdout=dup(1);
+    int new_stderr=dup(2);
+
+    close(1);
+    close(2);
+#endif
     if (fpp!=NULL) {
       vdirval=10;
     }
@@ -463,7 +478,9 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	    dlclose(handle);
 	    continue;
 	  }
-	  
+
+	  is_unstable=0;
+
 	  (*f0r_init)();
 	  (*f0r_get_plugin_info)(&f0rinfo);
 	  
@@ -523,7 +540,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	  }
 
 	  out_chantmpls=weed_malloc(2*sizeof(weed_plant_t *));
-	  out_chantmpls[0]=weed_channel_template_init("out channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,pal);
+	  out_chantmpls[0]=weed_channel_template_init("out channel 0",WEED_CHANNEL_REINIT_ON_ROWSTRIDES_CHANGE,pal);
 	  weed_set_int_value(out_chantmpls[0],"hstep",8);
 	  weed_set_int_value(out_chantmpls[0],"vstep",8);
 	  weed_set_int_value(out_chantmpls[0],"maxwidth",2048);
@@ -537,7 +554,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	    break;
 	  case F0R_PLUGIN_TYPE_FILTER:
 	    in_chantmpls=weed_malloc(2*sizeof(weed_plant_t *));
-	    in_chantmpls[0]=weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,pal);
+	    in_chantmpls[0]=weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_ROWSTRIDES_CHANGE,pal);
 	    weed_set_int_value(in_chantmpls[0],"hstep",8);
 	    weed_set_int_value(in_chantmpls[0],"vstep",8);
 	    weed_set_int_value(in_chantmpls[0],"maxwidth",2048);
@@ -547,14 +564,14 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	    break;
 	  case F0R_PLUGIN_TYPE_MIXER2:
 	    in_chantmpls=weed_malloc(3*sizeof(weed_plant_t *));
-	    in_chantmpls[0]=weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,pal);
+	    in_chantmpls[0]=weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_ROWSTRIDES_CHANGE,pal);
 	    weed_set_int_value(in_chantmpls[0],"hstep",8);
 	    weed_set_int_value(in_chantmpls[0],"vstep",8);
 	    weed_set_int_value(in_chantmpls[0],"maxwidth",2048);
 	    weed_set_int_value(in_chantmpls[0],"maxheight",2048);
 	    weed_set_int_value(in_chantmpls[0],"alignment",16);
 	    
-	    in_chantmpls[1]=weed_channel_template_init("in channel 1",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,pal);
+	    in_chantmpls[1]=weed_channel_template_init("in channel 1",WEED_CHANNEL_REINIT_ON_ROWSTRIDES_CHANGE,pal);
 	    weed_set_int_value(in_chantmpls[1],"hstep",8);
 	    weed_set_int_value(in_chantmpls[1],"vstep",8);
 	    weed_set_int_value(in_chantmpls[1],"maxwidth",2048);
@@ -564,21 +581,21 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	    break;
 	  case F0R_PLUGIN_TYPE_MIXER3:
 	    in_chantmpls=weed_malloc(4*sizeof(weed_plant_t *));
-	    in_chantmpls[0]=weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,pal);
+	    in_chantmpls[0]=weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_ROWSTRIDES_CHANGE,pal);
 	    weed_set_int_value(in_chantmpls[0],"hstep",8);
 	    weed_set_int_value(in_chantmpls[0],"vstep",8);
 	    weed_set_int_value(in_chantmpls[0],"maxwidth",2048);
 	    weed_set_int_value(in_chantmpls[0],"maxheight",2048);
 	    weed_set_int_value(in_chantmpls[0],"alignment",16);
 	    
-	    in_chantmpls[1]=weed_channel_template_init("in channel 1",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,pal);
+	    in_chantmpls[1]=weed_channel_template_init("in channel 1",WEED_CHANNEL_REINIT_ON_ROWSTRIDES_CHANGE,pal);
 	    weed_set_int_value(in_chantmpls[1],"hstep",8);
 	    weed_set_int_value(in_chantmpls[1],"vstep",8);
 	    weed_set_int_value(in_chantmpls[1],"maxwidth",2048);
 	    weed_set_int_value(in_chantmpls[1],"maxheight",2048);
 	    weed_set_int_value(in_chantmpls[1],"alignment",16);
 	    
-	    in_chantmpls[2]=weed_channel_template_init("in channel 2",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,pal);
+	    in_chantmpls[2]=weed_channel_template_init("in channel 2",WEED_CHANNEL_REINIT_ON_ROWSTRIDES_CHANGE,pal);
 	    weed_set_int_value(in_chantmpls[2],"hstep",8);
 	    weed_set_int_value(in_chantmpls[2],"vstep",8);
 	    weed_set_int_value(in_chantmpls[2],"maxwidth",2048);
@@ -658,8 +675,14 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 		vald=0.;
 #ifdef CAN_GET_DEF
 		f0r_get_param_value(f0r_inst,(void **)&vald,pnum);
+		if (vald!=0.&&vald!=1.) {
+		  fprintf(stderr,"Warning, frei0r plugin %s by %s sets bad default value (%f) for boolean parameter %s.\nThis plugin may be unstable !\n",f0rinfo.name,f0rinfo.author,vald,pinfo.name);
+		  is_unstable=1;
+		}
+		if (vald<=0.5) vald=0.;
+		else vald=1.;
 #endif
-		in_params[wnum]=weed_switch_init((char *)pinfo.name,label,(int)vald);
+		in_params[wnum]=weed_switch_init((char *)pinfo.name,label,vald==0.?WEED_FALSE:WEED_TRUE);
 		weed_set_string_value(in_params[wnum],"description",(char *)pinfo.explanation);
 		if (num_weed_params>f0rinfo.num_params) sprintf(rfx_strings[pnum],"layout|p%d|",wnum);
 		break;
@@ -667,6 +690,14 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 		vald=0.;
 #ifdef CAN_GET_DEF
 		f0r_get_param_value(f0r_inst,(void **)&vald,pnum);
+
+		if (vald<0.||vald>1.) {
+		  fprintf(stderr,"Warning, frei0r plugin %s by %s sets bad default value (%f) for parameter %s.\nThis plugin may be unstable !\n",f0rinfo.name,f0rinfo.author,vald,pinfo.name);
+		  is_unstable=1;
+		  if (vald<0.) vald=0.;
+		  if (vald>1.) vald=1.;
+		}
+
 #endif
 		in_params[wnum]=weed_float_init((char *)pinfo.name,label,vald,0.,1.);
 		weed_set_string_value(in_params[wnum],"description",(char *)pinfo.explanation);
@@ -679,6 +710,28 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 		valcol.r=valcol.g=valcol.b=0.;
 #ifdef CAN_GET_DEF
 		f0r_get_param_value(f0r_inst,(void **)&valcol,pnum);
+
+		if (valcol.r<0.||valcol.r>1.) {
+		  fprintf(stderr,"Warning, frei0r plugin %s by %s sets bad default value red (%f) for parameter %s.\nThis plugin may be unstable !\n",f0rinfo.name,f0rinfo.author,vald,pinfo.name);
+		  is_unstable=1;
+		  if (valcol.r<0.) valcol.r=0.;
+		  if (valcol.r>1.) valcol.r=1.;
+		}
+
+		if (valcol.g<0.||valcol.g>1.) {
+		  fprintf(stderr,"Warning, frei0r plugin %s by %s sets bad default value green (%f) for parameter %s.\nThis plugin may be unstable !\n",f0rinfo.name,f0rinfo.author,vald,pinfo.name);
+		  is_unstable=1;
+		  if (valcol.g<0.) valcol.g=0.;
+		  if (valcol.g>1.) valcol.g=1.;
+		}
+
+		if (valcol.b<0.||valcol.b>1.) {
+		  fprintf(stderr,"Warning, frei0r plugin %s by %s sets bad default value blue (%f) for parameter %s.\nThis plugin may be unstable !\n",f0rinfo.name,f0rinfo.author,vald,pinfo.name);
+		  is_unstable=1;
+		  if (valcol.b<0.) valcol.b=0.;
+		  if (valcol.b>1.) valcol.b=1.;
+		}
+
 #endif
 		in_params[wnum]=weed_colRGBd_init((char *)pinfo.name,label,valcol.r,valcol.g,valcol.b);
 		weed_set_string_value(in_params[wnum],"description",(char *)pinfo.explanation);
@@ -688,6 +741,19 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 		valpos.x=valpos.y=0.;
 #ifdef CAN_GET_DEF
 		f0r_get_param_value(f0r_inst,(void **)&valpos,pnum);
+		if (valpos.x<0.||valpos.x>1.) {
+		  fprintf(stderr,"Warning, frei0r plugin %s by %s sets bad default value x-pos (%f) for parameter %s.\nThis plugin may be unstable !\n",f0rinfo.name,f0rinfo.author,vald,pinfo.name);
+		  is_unstable=1;
+		  if (valpos.x<0.) valpos.x=0.;
+		  if (valpos.x>1.) valpos.x=1.;
+		}
+
+		if (valpos.y<0.||valpos.y>1.) {
+		  fprintf(stderr,"Warning, frei0r plugin %s by %s sets bad default value x-pos (%f) for parameter %s.\nThis plugin may be unstable !\n",f0rinfo.name,f0rinfo.author,vald,pinfo.name);
+		  is_unstable=1;
+		  if (valpos.y<0.) valpos.y=0.;
+		  if (valpos.y>1.) valpos.y=1.;
+		}
 #endif
 		in_params[wnum]=weed_float_init((char *)pinfo.name,label,valpos.x,0.,1.);
 		weed_set_string_value(in_params[wnum],"description",(char *)pinfo.explanation);
@@ -710,7 +776,9 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 		valch=strdup("Frei0r");
 #endif
 		in_params[wnum]=weed_text_init((char *)pinfo.name,label,valch);
+#ifndef CAN_GET_DEF
 		free(valch);
+#endif
 		weed_set_string_value(in_params[wnum],"description",(char *)pinfo.explanation);
 		if (num_weed_params>f0rinfo.num_params) sprintf(rfx_strings[pnum],"layout|p%d|",wnum);
 		break;
@@ -726,7 +794,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 		if (in_params!=NULL) weed_free(in_params);
 		if (rfx_strings!=NULL) {
 		  int j;
-		  for (j=0;j<pnum;j++) free(rfx_strings[j]);
+		  for (j=0;j<pnum;j++) weed_free(rfx_strings[j]);
 		  weed_free(rfx_strings);
 		}
 		continue;
@@ -746,12 +814,16 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 
 	  filter_class=weed_filter_class_init(weed_name,(char *)f0rinfo.author,pversion,0,&frei0r_init,&frei0r_process,&frei0r_deinit,in_chantmpls,out_chantmpls,in_params,NULL);
 
+	  if (is_unstable) {
+	    weed_set_boolean_value(filter_class,"plugin_unstable",WEED_TRUE);
+	  }
+
 	  if (num_weed_params>f0rinfo.num_params) {
 	    gui=weed_filter_class_get_gui(filter_class);
 	    weed_set_string_value(gui,"layout_scheme","RFX");
 	    weed_set_string_value(gui,"rfx_delim","|");
 	    weed_set_string_array(gui,"rfx_strings",f0rinfo.num_params,rfx_strings);
-	    for (wnum=0;wnum<f0rinfo.num_params;wnum++) free(rfx_strings[wnum]);
+	    for (wnum=0;wnum<f0rinfo.num_params;wnum++) weed_free(rfx_strings[wnum]);
 	    weed_free(rfx_strings);
 	    rfx_strings=NULL;
 	  }
@@ -790,6 +862,11 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
     // end frei0r dirs
     if (curvdir!=NULL) closedir(curvdir);
 
+#ifndef DEBUG
+    dup2(new_stdout,1);
+    dup2(new_stderr,2);
+#endif
+
     if (num_filters==0) return NULL;
     weed_set_int_value(plugin_info,"version",package_version);
   }
