@@ -63,6 +63,8 @@ POSSIBILITY OF SUCH DAMAGES.
 #include <signal.h>
 #include <assert.h>
 
+#define QUOTEME(x) #x
+
 /// don't change this unless the backend is changed as well
 /// i.e. $GUI_BOOTSTRAP_FILE in smogrify
 #define BOOTSTRAP_NAME "/tmp/.smogrify"
@@ -632,12 +634,6 @@ typedef enum {
 
 // some useful functions
 
-//gui.c
-void  create_LiVES (void);
-void enable_record (void);
-void toggle_record (void);
-void disable_record (void);
-
 // interface.c
 process* create_processing (const gchar *text);
 void add_to_winmenu(void);
@@ -731,8 +727,9 @@ void do_locked_in_vdevs_error(void);
 void do_do_not_close_d (void);
 
 gboolean process_one (gboolean visible);
-void do_threaded_dialog(const gchar *text, gboolean has_cancel);
+void do_threaded_dialog(gchar *translated_text, gboolean has_cancel);
 void end_threaded_dialog(void);
+void threaded_dialog_spin (void);
 void response_ok (GtkButton *button, gpointer user_data);
 void response_cancel (GtkButton *button, gpointer user_data);
 void pump_io_chan(GIOChannel *iochan);
@@ -823,10 +820,13 @@ void set_palette_colours (void);
 void set_main_title(const gchar *filename, gint or_untitled_number);
 void set_record (void);
 
-// main.c - in progress
-weed_plant_t *weed_layer_new_from_video(gint fnum, gint frame);
-
 //gui.c
+//gui.c
+void  create_LiVES (void);
+void enable_record (void);
+void toggle_record (void);
+void disable_record (void);
+void make_custom_submenus(void);
 void fade_background(void);
 void unfade_background(void);
 void block_expose (void);
@@ -835,6 +835,7 @@ void frame_size_update(void);
 void splash_init(void);
 void splash_end(void);
 void splash_msg(const gchar *msg, gdouble pct);
+void add_message_scroller(GtkWidget *conter);
 
 // utils.c
 #ifdef IS_IRIX
