@@ -14,10 +14,17 @@
 #include "main.h"
 #include "pangotext.h"
 
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed.h"
+#include "weed/weed-palettes.h"
+#include "weed/weed-effects.h"
+#include "weed/weed-host.h"
+#else
 #include "../libweed/weed.h"
 #include "../libweed/weed-palettes.h"
 #include "../libweed/weed-effects.h"
 #include "../libweed/weed-host.h"
+#endif
 
 static int font_cmp(const void *p1, const void *p2); 
 
@@ -77,6 +84,7 @@ char **get_font_list(void) {
           qsort(font_list, num, sizeof(char *), font_cmp);
         }
       }
+      g_free(pff);
     }
   }
   return font_list;
