@@ -51,7 +51,7 @@ static GList *get_plugin_result (const gchar *command, const gchar *delim, gbool
   gchar *com;
   gchar buffer[65536];
 
-  pthread_mutex_lock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
 
   outfile=g_strdup_printf ("%s/.smogplugin.%d",prefs->tmpdir,getpid());
   com=g_strconcat (command," >",outfile,NULL);
@@ -82,35 +82,35 @@ static GList *get_plugin_result (const gchar *command, const gchar *delim, gbool
       }
     }
     g_free (outfile);
-    pthread_mutex_unlock(&mainw->gtk_mutex);
+    threaded_dialog_spin();
     return list;
   }
   g_free (com);
   if (!g_file_test (outfile, G_FILE_TEST_EXISTS)) {
     g_free (outfile);
-    pthread_mutex_unlock(&mainw->gtk_mutex);
+    threaded_dialog_spin();
     return NULL;
   }
-  pthread_mutex_unlock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
 
   while ((outfile_fd=open(outfile,O_RDONLY))==-1&&(count-->0||list_plugins)) {
     g_usleep (prefs->sleep_time);
   }
   
   if (!count) {
-    pthread_mutex_lock(&mainw->gtk_mutex);
+    threaded_dialog_spin();
     g_printerr (_("Plugin timed out on message %s\n"),command);
     g_free (outfile);
-    pthread_mutex_unlock(&mainw->gtk_mutex);
+    threaded_dialog_spin();
     return list;
   }
   
   bytes=read (outfile_fd,&buffer,65535);
   close (outfile_fd);
   unlink (outfile);
-  pthread_mutex_lock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   g_free (outfile);
-  pthread_mutex_unlock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   memset (buffer+bytes,0,1);
 
 #ifdef DEBUG_PLUGINS
@@ -126,17 +126,17 @@ static GList *get_plugin_result (const gchar *command, const gchar *delim, gbool
   pieces=get_token_count (buffer,delim[0]);
   array=g_strsplit(buffer,delim,pieces);
   for (i=0;i<pieces;i++) {
-    if ((buf=g_strdup(array[i]))!=NULL) {
-      buf=(g_strchomp (g_strchug(buf)));
+    if (array[i]!=NULL) {
+      buf=g_strdup(g_strchomp (g_strchug(array[i])));
       if (strlen (buf)||allow_blanks) {
 	list=g_list_append (list, buf);
       }
       else g_free(buf);
     }
   }
-  pthread_mutex_lock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   g_strfreev (array);
-  pthread_mutex_unlock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   return list;
 }
 
@@ -193,9 +193,9 @@ plugin_request_common (const gchar *plugin_type, const gchar *plugin_name, const
   else com=g_strdup (request);
   list_plugins=FALSE;
   reslist=get_plugin_result (com,delim,allow_blanks);
-  pthread_mutex_lock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   g_free(com);
-  pthread_mutex_unlock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   return reslist;
 }
 
@@ -240,9 +240,9 @@ GList *get_plugin_list (const gchar *plugin_type, gboolean allow_nonex, const gc
   }
   list_plugins=TRUE;
   pluglist=get_plugin_result (com,"|",FALSE);
-  pthread_mutex_lock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   g_free(com);
-  pthread_mutex_unlock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   return pluglist;
 }
 
@@ -736,7 +736,7 @@ _vppaw *on_vpp_advanced_clicked (GtkButton *button, gpointer user_data) {
 
   vppa->dialog = gtk_dialog_new ();
 
-  gtk_window_set_position (GTK_WINDOW (vppa->dialog), GTK_WIN_POS_CENTER);
+  gtk_window_set_position (GTK_WINDOW (vppa->dialog), GTK_WIN_POS_CENTER_ALWAYS);
   if (prefs->show_gui) {
     if (prefsw!=NULL) gtk_window_set_transient_for(GTK_WINDOW(vppa->dialog),GTK_WINDOW(prefsw->prefs_dialog));
     else {
@@ -1944,7 +1944,6 @@ const lives_clip_data_t *get_decoder_cdata(file *sfile) {
   while (decoder_plugin!=NULL) {
     lives_decoder_sys_t *dpsys=(lives_decoder_sys_t *)decoder_plugin->data;
 
-    //#define DEBUG_DECPLUG
 #ifdef DEBUG_DECPLUG
     g_print("trying decoder %s\n",dpsys->name);
 #endif
@@ -2027,7 +2026,7 @@ void unload_decoder_plugins(void) {
 lives_decoder_sys_t *open_decoder_plugin(const gchar *plname) {
   lives_decoder_sys_t *dplug;
 
-  gchar *plugname=g_strdup_printf ("%s%s%s/%s.so",prefs->lib_dir,PLUGIN_EXEC_DIR,PLUGIN_DECODERS,plname);
+  gchar *plugname;
   gboolean OK=TRUE;
   const gchar *err;
 
@@ -2040,6 +2039,7 @@ lives_decoder_sys_t *open_decoder_plugin(const gchar *plname) {
 
   dplug->name=NULL;
 
+  plugname=g_strdup_printf ("%s%s%s/%s.so",prefs->lib_dir,PLUGIN_EXEC_DIR,PLUGIN_DECODERS,plname);
   dplug->handle=dlopen(plugname,RTLD_LAZY);
   g_free (plugname);
 
@@ -2189,7 +2189,7 @@ void render_fx_get_params (lives_rfx_t *rfx, const gchar *plugin_name, gshort st
     return;
   }
 
-  pthread_mutex_lock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   rfx->num_params=g_list_length (parameter_list);
   rfx->params=g_malloc (rfx->num_params*sizeof(lives_param_t));
   
@@ -2337,7 +2337,7 @@ void render_fx_get_params (lives_rfx_t *rfx, const gchar *plugin_name, gshort st
   }
   g_list_free_strings (parameter_list);
   g_list_free (parameter_list);
-  pthread_mutex_unlock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
 }
 
 
@@ -2473,6 +2473,7 @@ void rfx_free_all (void) {
     rfx_free(&mainw->rendered_fx[i]);
   }
   g_free(mainw->rendered_fx);
+  mainw->rendered_fx=NULL;
 }
 
 
