@@ -225,6 +225,7 @@ typedef struct {
 
   gboolean instant_open;
   gboolean auto_deint;
+  gboolean auto_nobord;
 
   gint gui_monitor;
   gint play_monitor;
@@ -274,7 +275,7 @@ typedef struct {
   gint nfx_threads;
 
   gboolean stream_audio_out;
-
+  gboolean unstable_fx;
 } _prefs;
 
 enum {
@@ -429,6 +430,7 @@ typedef struct {
   GtkWidget *checkbutton_render_prompt;
   GtkWidget *checkbutton_instant_open;
   GtkWidget *checkbutton_auto_deint;
+  GtkWidget *checkbutton_nobord;
   GtkWidget *checkbutton_concat_images;
   GtkWidget *forcesmon;
   GList *pbq_list;
