@@ -603,7 +603,7 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
       array=g_strsplit(lmap->data,"|",-1);
       text=g_strdup_printf("%s\n",array[0]);
       gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,g_strdup(array[0]));
+      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
       g_free(text);
       g_strfreev(array);
       lmap=lmap->next;
@@ -614,7 +614,7 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
     if (affects_current) {
       text=g_strdup_printf("%s\n",mainw->cl_string);
       gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,g_strdup(mainw->cl_string));
+      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,mainw->cl_string);
       g_free(text);
 
       gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter);
@@ -626,7 +626,7 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
       array=g_strsplit(lmap->data,"|",-1);
       text=g_strdup_printf("%s\n",array[0]);
       gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,g_strdup(array[0]));
+      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
       g_free(text);
       g_strfreev(array);
       lmap=lmap->next;
@@ -638,7 +638,7 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
     if (affects_current) {
       text=g_strdup_printf("%s\n",mainw->cl_string);
       gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,g_strdup(mainw->cl_string));
+      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,mainw->cl_string);
       g_free(text);
 
       gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter);
@@ -651,7 +651,7 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
       resampled_frame=count_resampled_frames(frameno,orig_fps,mainw->files[clipno]->fps);
       if (resampled_frame<=atoi(array[2])) {
 	text=g_strdup(array[0]);
-	mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,g_strdup(array[0]));
+	mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
 	if (g_list_find(mainw->affected_layouts_map,array[0])==NULL) mainw->affected_layouts_map=g_list_append(mainw->affected_layouts_map,g_strdup(array[0]));
 	g_free(text);
       }
@@ -665,7 +665,7 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
     if (affects_current) {
       text=g_strdup_printf("%s\n",mainw->cl_string);
       gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,g_strdup(mainw->cl_string));
+      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,mainw->cl_string);
       g_free(text);
 
       gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter);
@@ -678,7 +678,7 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
       if (max_time>0.&&atime<=max_time) {
 	text=g_strdup(array[0]);
 	gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-	mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,g_strdup(array[0]));
+	mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
 	g_free(text);
       }
       g_strfreev(array);
@@ -732,9 +732,9 @@ gboolean check_for_lock_file(const gchar *set_name, gint type) {
   int lockpid;
 
   unlink(info_file);
-  pthread_mutex_lock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   dummyvar=system(com);
-  pthread_mutex_unlock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   g_free(com);
 
   clear_mainw_msg();
@@ -748,9 +748,9 @@ gboolean check_for_lock_file(const gchar *set_name, gint type) {
 
       if (type==0) {
 	msg=g_strdup_printf(_("Set %s\ncannot be opened, as it is in use\nby another copy of LiVES.\n"),set_name);
-	pthread_mutex_lock(&mainw->gtk_mutex);
+	threaded_dialog_spin();
 	do_error_dialog(msg);
-	pthread_mutex_unlock(&mainw->gtk_mutex);
+	threaded_dialog_spin();
       }
       else if (type==1) {
 	msg=g_strdup_printf(_("\nThe set %s is currently in use by another copy of LiVES.\nPlease choose another set name.\n"),set_name);
@@ -1373,7 +1373,7 @@ get_play_times(void) {
 	  make_preview_box();
 	}
 	// and add it the play window
-	if (mainw->preview_box->parent==NULL&&cfile->clip_type==CLIP_TYPE_DISK&&!mainw->is_rendering) {
+	if (mainw->preview_box->parent==NULL&&(cfile->clip_type==CLIP_TYPE_DISK||cfile->clip_type==CLIP_TYPE_FILE)&&!mainw->is_rendering) {
 	  gtk_widget_queue_draw(mainw->play_window);
 	  gtk_container_add (GTK_CONTAINER (mainw->play_window), mainw->preview_box);
 	}
@@ -1462,8 +1462,6 @@ void draw_little_bars (gdouble ptrtime) {
 
   if (!prefs->show_gui) return;
 
-  if (pthread_mutex_trylock(&mainw->gtk_mutex)) return;
-
   if (!(frame=calc_frame_from_time(mainw->current_file,ptrtime)))
    frame=cfile->frames;
 
@@ -1570,7 +1568,7 @@ void draw_little_bars (gdouble ptrtime) {
       }
     }
   }
-  pthread_mutex_unlock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
 }
 
 
@@ -2166,6 +2164,7 @@ reset_clip_menu (void) {
 
   int i;
   GtkWidget *active_image=NULL;
+  gchar menutext[32768];
 
   for (i=1;i<=MAX_FILES;i++) {
     if (!(mainw->files[i]==NULL)) {
@@ -2184,7 +2183,9 @@ reset_clip_menu (void) {
 	gtk_widget_show (active_image);
       }
       if (mainw->files[i]->menuentry!=NULL) {
+	get_menu_text_long(mainw->files[i]->menuentry,menutext);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mainw->files[i]->menuentry), active_image);
+	set_menu_text(mainw->files[i]->menuentry,menutext,FALSE);
 	gtk_widget_queue_draw(mainw->files[i]->menuentry);
       }
     }
@@ -2679,9 +2680,9 @@ void cache_file_contents(const gchar *filename) {
 
   if (!(hfile=fopen(filename,"r"))) return;
   while (fgets(buff,65536,hfile)!=NULL) {
-    pthread_mutex_lock(&mainw->gtk_mutex);
+    threaded_dialog_spin();
     mainw->cached_list=g_list_append(mainw->cached_list,g_strdup(buff));
-    pthread_mutex_unlock(&mainw->gtk_mutex);
+    threaded_dialog_spin();
   }
   fclose(hfile);
 }
@@ -2858,22 +2859,22 @@ gboolean get_clip_value(int which, lives_clip_details_t what, void *retval, size
     val=g_malloc(maxlen);
     memset(val,0,maxlen);
     
-    pthread_mutex_lock(&mainw->gtk_mutex);
+    threaded_dialog_spin();
     if (system(com)) {
       tempdir_warning();
-      pthread_mutex_unlock(&mainw->gtk_mutex);
+      threaded_dialog_spin();
       g_free(com);
       return FALSE;
     }
     
     vfile=g_strdup_printf("%s/.smogval.%d.%d",prefs->tmpdir,getuid(),getpid());
-    pthread_mutex_unlock(&mainw->gtk_mutex);
+    threaded_dialog_spin();
     do {
       if (!(valfile=fopen(vfile,"r"))) {
 	if (!(mainw==NULL)) {
-	  pthread_mutex_lock(&mainw->gtk_mutex);
+	  threaded_dialog_spin();
 	  while (g_main_context_iteration(NULL,FALSE));
-	  pthread_mutex_unlock(&mainw->gtk_mutex);
+	  threaded_dialog_spin();
 	}
 	g_usleep(prefs->sleep_time);
 	timeout--;
@@ -3275,10 +3276,10 @@ void
 get_border_size (GtkWidget *win, gint *bx, gint *by) {
   GdkRectangle rect;
   gint wx,wy;
-  pthread_mutex_lock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   gdk_window_get_frame_extents (GDK_WINDOW (win->window),&rect);
   gdk_window_get_origin (GDK_WINDOW (win->window), &wx, &wy);
-  pthread_mutex_unlock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   bx[0]=wx-rect.x;
   by[0]=wy-rect.y;
 }
